(************************************************************************
*    This File is Part of the AHM Triton Tools                          *
*    for Borland Delphi and C++ Builder.                                *
*************************************************************************
* Copyright  1995-2000 Alexander H. Mehlhorn (AHM) and Tritontools.com *
* All Rights reserved.                                                  *
*                                                                       *
*    For more Information contact us at                                 *
*    E-Mail : support@tritontools.com                                   *
*    URL : http://www.tritontools.com                                   *
*                                                                       *
*    AHM is copyright by Alexander H. Mehlhorn                          *
*    All Parts of this Collection were developed,                       *
*    designed and implemented by AHM                                    *
*                                                                       *
*    Under no Circumstances may you distribute this file                *
*    in this or any other format. This File is supplied                 *
*    as Evaluation of Source only. No Delphi Components may be developed*
*    using extracts or subsets of this code without expressed permission*
*    by AHM.                                                            *
*                                                                       *
*************************************************************************)
unit AHMTFadingLabel;

interface

uses
  SysUtils, Windows, Controls,Dialogs,forms,AHMFreeware,
  ExtCtrls, Classes, Graphics, Menus,StdCtrls;

type
  TAHMFadingLabel = class(TCustomLabel)
  private
    FAbout : TAHMAboutFreeStr;
    ftim : TTimer;
    fonv,fontv : TNotifyevent;
    fcol : TColor;
    fis : Boolean;
    ffade : Boolean;
    fi : Integer;
    fint : Integer;
    fdel : Integer;
    TempRect:TRect;
    flags : Longint;
    fconst : Boolean;
    fupdown : boolean;
    fspeed : Integer;
    procedure Setis(value : Boolean);
    procedure Setfade(value : Boolean);
    procedure Setcol(Sender : TObject);
    procedure SetSpeed(value : Integer);
    procedure DrawLabel;
    procedure SetInt(value : Integer);
  protected
    procedure Paint; override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure Execute;
    procedure Loaded; override;
  published
    Property About : TAHMAboutFreeStr read FAbout write FAbout;
    property Align;
    property Alignment;
    property Color;
    property AutoSize;
    property Caption;
    property Enabled;
    property FocusControl;
    property Font;
    property Showing : Boolean read fis write Setis;
    property Fade : Boolean read ffade write Setfade;
    property BetweenColors : Integer read fint write SetInt;
    property FadeAlltheTime : Boolean read fconst write fconst;
    property FadeSpeed : Integer read fspeed write Setspeed;
    property ShowHint;
    property Visible;
    property OnClick;
    property OnDblClick;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
    property OnNotVisible : TNotifyevent read fonv write fonv;
    Property OnTotallyVisible : TNotifyevent read fontv write fontv;
  end;
implementation

constructor TAHMFadingLabel.Create(AOwner: TComponent);
begin
  fi:=1;
  fint:=16;
  fcol:=color;
  fdel:=20;
  fspeed:=2;
  inherited Create(AOwner);
  ftim:=TTimer.create(self);
  ffade:=true;
  fconst:=true;
  ftim.enabled:=true;
  ftim.OnTimer:=setcol;
  ftim.Interval:=2;
  Transparent := True;
end;

procedure TAHMFadingLabel.Loaded;
begin
  inherited Loaded;
end;


destructor TAHMFadingLabel.Destroy;
begin
  ftim.free;
  inherited destroy;
end;

procedure TAHMFadingLabel.Paint;
const Alignments: array[TAlignment] of Word = (DT_LEFT, DT_RIGHT, DT_CENTER);
begin
  Canvas.brush.style:=bssolid;
  Canvas.brush.color:=Color;
  TempRect:=Clientrect;
  Canvas.Fillrect(tempRect);
  flags:=DT_EXPANDTABS or DT_WORDBREAK or Alignments[Alignment];
  Canvas.Brush.Style := bsClear;
  Canvas.Font := Self.Font;
  Canvas.Brush.Style := bsClear;
  Text := GetLabelText;
  if (Flags and DT_CALCRECT <> 0) and ((Text = '') or ShowAccelChar and
    (Text[1] = '&') and (Text[2] = #0)) then Text := Text + ' ';
  if not ShowAccelChar then Flags := Flags or DT_NOPREFIX;
  drawlabel;
end;

procedure TAHMFadingLabel.DrawLabel;
var acol : TColor;

begin
  Temprect:=Clientrect;
  Canvas.brush.style:=bsclear;
  if not Enabled then Canvas.Font.Color := clGrayText
  else
  begin
    acol:=Canvas.Font.color;
    Canvas.Font.color:=fcol;
    DrawText(Canvas.handle,Pchar(Text),-1,Temprect,flags);
    Canvas.Font.color:=acol;
  end;
end;

procedure TAHMFadingLabel.SetSpeed(value : Integer);
begin
  fspeed:=value;
  ftim.Interval:=value;
end;

procedure TAHMFadingLabel.SetInt(Value : Integer);
begin
  if (value>0) and (Value<256) then fint:=value;
end;

procedure TAHMFadingLabel.Setcol(Sender : TObject);
var
  R         : Byte;
  G         : Byte;
  B         : Byte;
  BeginRGBValue  : array[0..2] of Byte;
  RGBDifference  : array[0..2] of Integer;
begin
  if fupdown then inc(fi)
  else dec(fi);
  if ffade then
  begin
  BeginRGBValue[0] := GetRValue(ColorToRGB(color));
  BeginRGBValue[1] := GetGValue(ColorToRGB(color));
  BeginRGBValue[2] := GetBValue(ColorToRGB(color));
  RGBDifference[0] := GetRValue(ColorToRGB(font.color)) -
                      BeginRGBValue[0];
  RGBDifference[1] := GetGValue (ColorToRGB(font.color)) -
                      BeginRGBValue[1];
  RGBDifference[2] := GetBValue (ColorToRGB(font.color)) -
                      BeginRGBValue[2];
  R := BeginRGBValue[0] + round(MulDiv (fi, RGBDifference[0],fint - 1));
  G := BeginRGBValue[1] + round(MulDiv (fi, RGBDifference[1],fint - 1));
  B := BeginRGBValue[2] + round(MulDiv (fi, RGBDifference[2],fint - 1));
  fcol:=RGB (R, G, B);
  Drawlabel;
  end;
  if fi>=fint-1 then
  begin
    fupdown:=false;
    if not(fconst) then Setfade(false);
    if assigned(fontv) then fontv(self);
  end;
  if fi<=1 then
  begin
    fupdown:=true;
    if assigned(fonv) then fonv(self);
    if not(fconst) then Setfade(false);
  end;
  Application.processmessages;
end;


procedure TAHMFadingLabel.Setfade(value : Boolean);
begin
  ffade:=value;
  ftim.enabled:=value;
end;

procedure TAHMFadingLabel.Execute;
begin
  ftim.enabled:=not(ftim.enabled);
end;

procedure TAHMFadingLabel.Setis(value : Boolean);
begin
  fis:=value;
  if value then
  begin
    fi:=fint;
    Setcol(self);
  end
  else
  begin
    fi:=1;
    Setcol(self);
  end;
end;

end.

